from plone import api
from plone.dexterity.browser import add
from plone.dexterity.browser.edit import DefaultEditForm


def update_widgets(self):
    # remove default_timezone, it gets set
    # later in a subscriber
    start = self.widgets['IEventBasic.start']
    end = self.widgets['IEventBasic.end']
    start.default_timezone = None
    end.default_timezone = None
    self.widgets.update()


def set_timezone(self):
    # set the time_zone default value to site's tz
    # for certain types, get the tz value from the parent
    # and disable the field so it can't be changed
    tz_field = self.widgets['ITimeZones.time_zone']
    nav_root = api.portal.get_navigation_root(self.context)
    if nav_root.portal_type == 'conference':
        time_zone = nav_root.time_zone
    else:
        time_zone = api.portal.get_registry_record('plone.portal_timezone')
    tz_field.field.default = time_zone

    add_url = self.request.getURL().split('/')[-1]
    if add_url in ['++add++presentation', '++add++training_class']:
        tz_field.field.description = 'Time Zone set on parent conference'


class EventAddForm(add.DefaultAddForm):

    def updateWidgets(self, prefix=None):
        super(EventAddForm, self).updateWidgets()
        if 'ITimeZones.time_zone' not in self.widgets.keys():
            return
        set_timezone(self)
        start = self.widgets['IEventBasic.start']
        end = self.widgets['IEventBasic.end']
        start.default_timezone = None
        end.default_timezone = None
        self.widgets.update()


class EventAddView(add.DefaultAddView):
    form = EventAddForm


class EventEdit(DefaultEditForm):

    def updateWidgets(self, prefix=None):
        super(EventEdit, self).updateWidgets()
        if 'ITimeZones.time_zone' in self.widgets.keys():
            update_widgets(self)
